| ARIMAsetup | R Documentation |
Sets up ARIMA general models
ARIMAsetup(
y,
u = NULL,
model = NULL,
cnst = NULL,
s = frequency(y),
criterion = "bic",
h = 2 * s,
verbose = FALSE,
lambda = 1,
maxOrders = c(3, 2, 3, 2, 1, 2),
bootstrap = FALSE,
nSimul = 5000,
fast = FALSE
)
y |
a time series to forecast (it may be either a numerical vector or
a time series object). This is the only input required. If a vector, the additional
input |
u |
a matrix of input time series. If
the output wanted to be forecast, matrix |
model |
the model to estimate. A vector c(p,d,q,P,D,Q) containing the model orders of an ARIMA(p,d,q)x(P,D,Q)_s model. A constant may be estimated with the cnst input. Use a NULL to automatically identify the ARIMA model. |
cnst |
flag to include a constant in the model (TRUE/FALSE/NULL). Use NULL to estimate |
s |
seasonal period of time series (1 for annual, 4 for quarterly, ...) |
criterion |
information criterion for identification stage ("aic", "bic", "aicc") |
h |
forecast horizon. If the model includes inputs h is not used, the lenght of u is used instead. |
verbose |
intermediate estimation output (TRUE / FALSE) |
lambda |
Box-Cox lambda parameter (NULL: estimate) |
maxOrders |
a vector c(p,d,q,P,D,Q) containing the maximum orders of model orders to search for in the automatic identification |
bootstrap |
use bootstrap simulation for predictive distributions |
nSimul |
number of simulation runs for bootstrap simulation of predictive distributions |
fast |
fast identification (avoids post-identification checks) |
See help of ARIMAforecast.
An object of class ARIMA. It is a list with fields including all the inputs and
the fields listed below as outputs. All the functions in this package fill in
part of the fields of any ARIMA object as specified in what follows (function
ARIMA fills in all of them at once):
After running ARIMAforecast or ARIMA:
p |
Estimated parameters |
yFor |
Forecasted values of output |
yForV |
Variance of forecasted values of output |
ySimul |
Bootstrap simulations for forecasting distribution evaluation |
After running ARIMAvalidate:
table |
Estimation and validation table |
Diego J. Pedregal
ARIMA, ARIMAforecast, ARIMAvalidate,
y <- log(AirPassengers)
m1 <- ARIMAsetup(y)
m1 <- ARIMAsetup(y, lambda = NULL)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.