ETSestim: ETSestim

View source: R/ETSestim.R

ETSestimR Documentation

ETSestim

Description

Estimates and forecasts ETS models

Usage

ETSestim(m)

Arguments

m

an object of type ETS created with ETSforecast

Details

ETSestim estimates and forecasts a time series using an an ETS model

Value

The same input object with the appropriate fields filled in, in particular:

p

Estimated parameters

yFor

Forecasted values of output

yForV

Variance of forecasted values of output

ySimul

Bootstrap simulations for forecasting distribution evaluation

Author(s)

Diego J. Pedregal

See Also

ETS, ETSforecast, ETSvalidate, ETScomponents

Examples


m1 <- ETSsetup(log(gdp))
m1 <- ETSestim(m1)


UComp documentation built on April 24, 2026, 5:07 p.m.

Related to ETSestim in UComp...