UCcomponents: UCcomponents

View source: R/UCestim.R

UCcomponentsR Documentation

UCcomponents

Description

Estimates unobserved components of UC models Standard methods applicable to UComp objects are print, summary, plot, fitted, residuals, logLik, AIC, BIC, coef, predict, tsdiag.

Usage

UCcomponents(sys)

Arguments

sys

an object of type UComp created with UC or UCforecast

Value

The same input object with the appropriate fields filled in, in particular:

  • comp: Estimated components in matrix form

  • compV: Estimated components variance in matrix form

Author(s)

Diego J. Pedregal

See Also

UC, UCforecast, UCvalidate, UCfilter, UCsmooth, UCdisturb, UChp

Examples


m1 <- UC(log(AirPassengers))
m1 <- UCcomponents(m1)


UComp documentation built on April 24, 2026, 5:07 p.m.

Related to UCcomponents in UComp...