extract: extract

View source: R/tools.R

extractR Documentation

extract

Description

Reorder data frame returning column col reordered according to the values in column accordingTo

Usage

extract(x, col, accordingTo = 1)

Arguments

x

a data frame

col

column to be ordered

accordingTo

column to take as the pattern

Value

Data frame reordered accoring to a given column data

Author(s)

Diego J. Pedregal


UComp documentation built on April 24, 2026, 5:07 p.m.

Related to extract in UComp...