predict.UComp: predict.UComp

View source: R/UCS3functions.R

predict.UCompR Documentation

predict.UComp

Description

Forecasting using structural Unobseved Components models with prediction intervals

Usage

## S3 method for class 'UComp'
predict(object, newdata = NULL, n.ahead = NULL, level = 0.95, ...)

Arguments

object

Object of class “UComp”.

newdata

New output data to apply “UComp” object to.

n.ahead

Number of steps ahead to forecast or new inputs variables including their predictions.

level

Confidence level for prediction intervals.

...

Ignored.

Details

See help of UC.

Value

Forecasts of a UC model

A matrix with the mean forecasts and lower and upper prediction intervals

Author(s)

Diego J. Pedregal

See Also

UC, UCforecast, UCvalidate, UCfilter, UCsmooth, UCdisturb, UCcomponents

Examples


y <- log(AirPassengers)
m1 <- UCforecast(y, model = "llt/eq/arma(0,0)")
f1 <- predict(m1)


UComp documentation built on April 24, 2026, 5:07 p.m.

Related to predict.UComp in UComp...