| slideAux | R Documentation |
Auxiliary function run from slide
slideAux(
y,
orig,
forecFun,
h = 12,
step = 1,
output = TRUE,
graph = TRUE,
window = NA,
parallel = FALSE,
isList = FALSE,
...
)
y |
a vector or matrix of time series |
orig |
starting forecasting origin |
forecFun |
user function that implements forecasting methods |
h |
forecasting horizon |
step |
observations ahead to move the forecasting origin |
output |
output TRUE/FALSE |
graph |
fraphical output TRUE/FALSE |
window |
fixed window width in number of observations (NA for non fixed) |
parallel |
run forecasts in parallel |
isList |
whether the input data y is a list or a matrix |
... |
rest of inputs to forecFun function |
Auxiliary output of slide function for just one time series
Diego J. Pedregal
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.